<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Silvuple_Content extends \Elementor\Widget_Base { 
   /**
	 * Get widget name.
	 *
	 * Retrieve Card widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
 	public function get_style_depends() {
    	wp_enqueue_style( 'silvuple-content', plugins_url( '../assets/css/content.css' , __FILE__ ));

        return [
            'silvuple-content',
        ];
    }
	public function get_name() {
		return 'content';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Card widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Silvuple RSVP - Content', 'silvuple' );
	}

    /**
	 * Get widget icon.
	 *
	 * Retrieve Card widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-form-horizontal';
	}

    /**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://www.modeltheme.com/';
	}

    /**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Card widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

    /**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the Card widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'silvuple', 'content', 'invitation' ];
	}

	public function get_link() {
		return 'link';
	}
    /**
	 * Register Card widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */

	protected function register_controls() { 
		// our control function code goes here.
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content Section', 'silvuple' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'template_version',
			[
				'label' => esc_html__( 'Version', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Select Template', 'silvuple' ),
					'v1' => esc_html__( 'V1', 'silvuple' ),
					'v2' => esc_html__( 'V2', 'silvuple' ),
					'v3' => esc_html__( 'V3', 'silvuple' ),
				],
				'default' => 'v1',
			]
		);
		$this->add_control(
			'background_image',
			[
				'label' => esc_html__( 'Choose Background Image', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				
			]
		);
		$this->add_control(
            'background_image_position',
            [
                'label'                => esc_html__( 'Background Image Position', 'silvuple' ),
				'type' 				   => \Elementor\Controls_Manager::CHOOSE,
                'options'              => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'silvuple' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'silvuple' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'              => 'left',
                'selectors_dictionary' => [
                    'left'  => 'flex-flow: inherit',
                    'right' => 'flex-direction:row-reverse',
                ],
                'toggle'               => false,
                'selectors'            => [
                    '{{WRAPPER}} .silvuple-content-bg-container' => '{{VALUE}}',
                ],
               
            ]
        );
		$this->add_group_control(
	        \Elementor\Group_Control_Typography::get_type(),
	        [
				'label' => esc_html__( 'Header Primary Typography', 'silvuple' ),
	            'name' => 'header_typography',
	            'selector' => '{{WRAPPER}} .silvuple-element-header1',
	        ]
	    );
	    $this->add_group_control(
	        \Elementor\Group_Control_Typography::get_type(),
	        [
				'label' => esc_html__( 'Header Secondary Typography', 'silvuple' ),
	            'name' => 'header_secondary',
	            'selector' => '{{WRAPPER}} .silvuple-element-header2',
	        ]
	    );
	    $this->add_group_control(
	        \Elementor\Group_Control_Typography::get_type(),
	        [
				'label' => esc_html__( 'Paragraph Typography', 'silvuple' ),
	            'name' => 'paragraph',
	            'selector' => '{{WRAPPER}} .silvuple-element-paragraph',
	        ]
	    );  
	    $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Button Typography', 'silvuple' ),
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .silvuple-content-button a',
			]
		);
	    $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Phone Typography', 'silvuple' ),
				'name' => 'phone_typography',
				'selector' => '{{WRAPPER}} .silvuple-content-phone',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .silvuple-content-container',
			]
		);
		$this->add_control(
			'show_box_shadow',
			[
				'label' => esc_html__( 'Box shadow?', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'show_shadow' => esc_html__( 'Yes', 'silvuple' ),
					'no_shadow' => esc_html__( 'No', 'silvuple' ),
				],
				'default' => 'no_shadow',
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'type',
			[
				'label' => esc_html__( 'Info Type', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'Header',
				'options' => [
					'header_primary' => esc_html__( 'Heading Primary', 'silvuple' ),
					'header_secondary' => esc_html__( 'Heading Secondary', 'silvuple' ),
					'paragraph' => esc_html__( 'Paragraph', 'silvuple' ),
					'btn_phone' => esc_html__( 'Phone', 'silvuple' ),
					'btn_button' => esc_html__( 'Button', 'silvuple' ),
					'separator' => esc_html__( 'Separator', 'silvuple' ),
					'contact_form' => esc_html__( 'Contact Form', 'silvuple' ),
					'spacer' => esc_html__( 'Spacer', 'silvuple' ),
					'content_image' => esc_html__( 'Image', 'silvuple' ),
				],
				'default' => 'header_primary',
			]
		);
		$repeater->add_control(
			'header_primary_options',
			[
				'label' => esc_html__( 'Heading Primary Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'header_primary',
	            ],
			]
		);
		$repeater->add_control(
			'header_text',
			[
				'label' => esc_html__( 'Heading text', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your text here', 'silvuple' ),
				'default' => 'What’s New',
				'condition' => [
	              	'type' => 'header_primary',
	            ],
			]
		);
		$repeater->add_control(
			'header_alignment',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Heading Alignment', 'silvuple' ),
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'silvuple' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'silvuple' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'silvuple' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
	              	'type' => 'header_primary',
	            ],
			]
		); 

		$repeater->add_control(
			'header_color',
			[
				'label' => esc_html__( 'Heading Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'condition' => [
		            'type' => 'header_primary',
		        ],
			]
		);
		$repeater->add_control(
			'header_secondary_options',
			[
				'label' => esc_html__( 'Heading Secondary Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'header_secondary',
	            ],
			]
		);
		$repeater->add_control(
			'header_secondary_text',
			[
				'label' => esc_html__( 'Heading Secondary text', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'What’s New',
				'placeholder' => esc_html__( 'Type your text here', 'silvuple' ),
				'condition' => [
	              	'type' => 'header_secondary',
	            ],
			]
		);
		$repeater->add_control(
			'header_secondary_alignment',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Heading Alignment', 'silvuple' ),
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'silvuple' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'silvuple' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'silvuple' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
	              	'type' => 'header_secondary',
	            ],
			]
		); 						
		$repeater->add_control(
			'header_secondary_color',
			[
				'label' => esc_html__( 'Heading Secondary Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'condition' => [
		            'type' => 'header_secondary',
		        ],
			]
		);
		$repeater->add_control(
			'paragraph_options',
			[
				'label' => esc_html__( 'Paragraph Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'paragraph',
	            ],
			]
		);
		$repeater->add_control(
			'paragraph_text',
			[
				'label' => esc_html__( 'Paragraph text', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'What’s New',
				'placeholder' => esc_html__( 'Type your text here', 'silvuple' ),
				'condition' => [
	              	'type' => 'paragraph',
	            ],
			]
		);
		$repeater->add_control(
			'paragraph_alignment',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Paragraph Alignment', 'silvuple' ),
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'silvuple' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'silvuple' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'silvuple' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
	              	'type' => 'paragraph',
	            ],
			]
		); 						
		$repeater->add_control(
			'paragraph_color',
			[
				'label' => esc_html__( 'Paragraph Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'condition' => [
		            'type' => 'paragraph',
		        ],
			]
		);
		$repeater->add_control(
			'phone_options',
			[
				'label' => esc_html__( 'Phone Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'btn_phone',
	            ],
			]
		);
		$repeater->add_control(
			'phone_number',
			[
				'label' => esc_html__( 'Phone Number', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '+1-541-754-3010',
				'placeholder' => esc_html__( 'Type your number here', 'silvuple' ),
				'condition' => [
	              	'type' => 'btn_phone',
	            ],
			]
		);
		$repeater->add_control(
			'phone_alignment',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Phone Alignment', 'silvuple' ),
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'silvuple' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'silvuple' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'silvuple' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
	              	'type' => 'btn_phone',
	            ],
			]
		);
		$repeater->add_control(
			'phone_color',
			[
				'label' => esc_html__( 'Phone Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'condition' => [
	              	'type' => 'btn_phone',
	            ],
			]
		);
		$repeater->add_control(
			'button_options',
			[
				'label' => esc_html__( 'Button Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'btn_button',
	            ],
			]
		);
		$repeater->add_control(
			'button_text',
			[
				'label' => esc_html__( 'Text for your button', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Click me',
				'placeholder' => esc_html__( 'Type your ID here', 'silvuple' ),
				'condition' => [
	              	'type' => 'btn_button',
	            ],
			]
		);
		$repeater->add_control(
			'button_alignment',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Button Alignment', 'silvuple' ),
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'silvuple' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'silvuple' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'silvuple' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
	              	'type' => 'btn_button',
	            ],
			]
		);
		$repeater->add_control(
			'button_background_color',
			[
				'label' => esc_html__( 'Button Background Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#000',
				'condition' => [
	              	'type' => 'btn_button',
	            ],
			]
		);
		$repeater->add_control(
			'button_color',
			[
				'label' => esc_html__( 'Button Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .silvuple-button' => 'color: {{VALUE}}',
				],
				'default' => '#fff',
				'condition' => [
	              	'type' => 'btn_button',
	            ],
			]
		);
		$repeater->add_control(
			'button_type',
			[
				'label' => esc_html__( 'Button Type', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'button_link' => esc_html__( 'Button Link', 'silvuple' ),
					'email_link' => esc_html__( 'Email', 'silvuple' ),
				],
				'condition' => [
	              	'type' => 'btn_button',
	            ],
				'default' => 'button_link',
			]
		);
		$repeater->add_control(
			'button_url_link',
			[
				'label' => esc_html__( 'Button Link', 'meeek' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'meeek' ),
				'options' => [ 'url', 'is_external', 'nofollow' ],
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
	            'condition' => [
	            	'button_type' => 'button_link', 
	            	'type' => 'btn_button'
	            ],
				'label_block' => true,
				
			]
		);
	    $repeater->add_control(
			'button_email_link',
			[
				'label' => esc_html__( 'Your Email', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Type your Email here', 'silvuple' ),
				'condition' => [
	              	'button_type' => 'email_link',
	            ],
			]
		);
		$repeater->add_control(
			'email_subject',
			[
				'label' => esc_html__( 'Email Subject', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Type your Email Subject here', 'silvuple' ),
				'condition' => [
	              	'button_type' => 'email_link',
	            ],
			]
		);
		$repeater->add_control(
			'email_cc',
			[
				'label' => esc_html__( 'Email CC', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Type your Email CC here', 'silvuple' ),
				'condition' => [
	              	'button_type' => 'email_link',
	            ],
			]
		);	
		$repeater->add_control(
			'email_bcc',
			[
				'label' => esc_html__( 'Email BCC', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Type your Email BCC here', 'silvuple' ),
				'condition' => [
	              	'button_type' => 'email_link',
	            ],
			]
		);
		$repeater->add_control(
			'email_body',
			[
				'label' => esc_html__( 'Email Body', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your Email Body here', 'silvuple' ),
				'condition' => [
	              	'button_type' => 'email_link',
	            ],
			]
		);
		$repeater->add_control(
			'separator_options',
			[
				'label' => esc_html__( 'Separator Options', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'separator',
	            ],
			]
		);
		$repeater->add_control(
			'separator_border',
			[
				'label' => esc_html__( 'Border Type', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'' => esc_html__( 'Default', 'silvuple' ),
					'none' => esc_html__( 'None', 'silvuple' ),
					'solid'  => esc_html__( 'Solid', 'silvuple' ),
					'dashed' => esc_html__( 'Dashed', 'silvuple' ),
					'dotted' => esc_html__( 'Dotted', 'silvuple' ),
					'double' => esc_html__( 'Double', 'silvuple' ),
				],
				'condition' => [
	              	'type' => 'separator',
	            ],
			]
		);
		$repeater->add_control(
			'separator_width',
			[
				'label' => esc_html__( 'Separator Width', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '1',
				'condition' => [
	              	'type' => 'separator',
	            ],
			]
		);
		$repeater->add_control(
			'separator_color',
			[
				'label' => esc_html__( 'Separator Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#000',
				'condition' => [
	              	'type' => 'separator',
	            ],
			]
		);
        $repeater->add_control(
			'contact_form',
			[
				'label' => esc_html__( 'Contact Form', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'contact_form',
	            ],
			]
		);
		$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
        $contact_form_id = array();
        if ( $cf7 ) {
	        foreach ( $cf7 as $cform ) {
	            $contact_form_id[ $cform->ID ] = $cform->post_title;
	        }
        } else {
            $contact_form_id[ esc_html__( 'No contact forms found', 'silvuple' ) ] = 0;
        }
        $repeater->add_control(
            'contact_form_id',
                [
                    'label' => __( 'Select Contact Form', 'silvuple' ),
                    'label_block' => true,
					'type' => \Elementor\Controls_Manager::SELECT,
                    'options' => $contact_form_id,
                    'condition' => [
		              	'type' => 'contact_form',
		            ],
                ]
        );
		$repeater->add_control(
			'spacer_heading',
			[
				'label' => esc_html__( 'Spacer', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'spacer',
	            ],
			]
		);
		$repeater->add_control(
			'spacer',
			[
				'label' => esc_html__( 'Spacer Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '0',
				'condition' => [
	              	'type' => 'spacer',
	            ],
			]
		);
		$repeater->add_control(
			'content_image_options',
			[
				'label' => esc_html__( 'Background Image', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
	              	'type' => 'content_image',
	            ],
			]
		);
		$repeater->add_control(
			'image',
			[
				'label' => esc_html__( 'Choose Image', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
	              	'type' => 'content_image',
	            ],
			]
		);
		$repeater->add_control(
			'image_size',
			[
				'label' => esc_html__( 'Image Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '75',
				'condition' => [
	              	'type' => 'content_image',
	            ],
			]
		);
		$this->add_control(
	        'list',
	        [
	            'label' => esc_html__('Menu Items', 'silvuple'),
	            'type' => \Elementor\Controls_Manager::REPEATER,
	            'fields' => $repeater->get_controls(),
	            'prevent_empty' => false,
	        ]
	    );
		$this->end_controls_section();
	}

    /**
	 * Render Card widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() { 
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		// get the individual values of the input
		$list = $settings['list'];
		$background_image = $settings['background_image']['url'];
		$background_image_position = $settings['background_image_position'];
		$show_box_shadow = $settings['show_box_shadow'];
		$template_version = $settings['template_version'];


		echo do_shortcode('[silvuple-content list="' . base64_encode(serialize($list)) . '" background_image="' . esc_attr($background_image) . '" background_image_position="' . esc_attr($background_image_position) . '" show_box_shadow="' . esc_attr($show_box_shadow) . '" template_version="' . esc_attr($template_version) . '"]');
	}						
}