<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Silvuple_Timeline extends \Elementor\Widget_Base { 
   /**
   * Get widget name.
   *
   * Retrieve Card widget name.
   *
   * @since 1.0.0
   * @access public
   * @return string Widget name.
   */
 	public function get_style_depends() {
    	wp_enqueue_style( 'silvuple-timeline', plugins_url( '../assets/css/timeline.css' , __FILE__ ));

        return [
            'silvuple-timeline',
        ];
    }
  public function get_name() {
    return 'timeline';
  }
  /**
   * Get widget title.
   *
   * Retrieve Card widget title.
   *
   * @since 1.0.0
   * @access public
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Silvuple RSVP - Timeline', 'silvuple' );
  }
    /**
   * Get widget icon.
   *
   * Retrieve Card widget icon.
   *
   * @since 1.0.0
   * @access public
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-form-horizontal';
  }
    /**
   * Get custom help URL.
   *
   * Retrieve a URL where the user can get more information about the widget.
   *
   * @since 1.0.0
   * @access public
   * @return string Widget help URL.
   */
  public function get_custom_help_url() {
    return 'https://www.modeltheme.com/';
  }
    /**
   * Get widget categories.
   *
   * Retrieve the list of categories the Card widget belongs to.
   *
   * @since 1.0.0
   * @access public
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'general' ];
  }
    /**
   * Get widget keywords.
   *
   * Retrieve the list of keywords the Card widget belongs to.
   *
   * @since 1.0.0
   * @access public
   * @return array Widget keywords.
   */
  public function get_keywords() {
    return [ 'silvuple', 'timeline' ];
  }

  public function get_link() {
    return 'link';
  }
    /**
   * Register Card widget controls.
   *
   * Add input fields to allow the user to customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */

	protected function register_controls() {

		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Content', 'silvuple' ),
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'date',
			[
				'label' => esc_html__( 'Date of event', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'July 1, 2023',
			]
		);
		$repeater->add_control(
			'date_font_size',
			[
				'label' => esc_html__( 'Date Font Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'date_color',
			[
				'label' => esc_html__( 'Date Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'week_day',
			[
				'label' => esc_html__( 'Day of the Week', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Saturday',
			]
		);
		$repeater->add_control(
			'week_day_size',
			[
				'label' => esc_html__( 'Week Day Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'day_color',
			[
				'label' => esc_html__( 'Day Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'hour',
			[
				'label' => esc_html__( 'Hour of the Event', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '4:30pm',
			]
		);
		$repeater->add_control(
			'hour_font_size',
			[
				'label' => esc_html__( 'Hour Day Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'hour_color',
			[
				'label' => esc_html__( 'Hour Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'event_status',
			[
				'label' => esc_html__( 'The Event Status', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'RECEPTION & DINNER',
			]
		);
		$repeater->add_control(
			'event_status_size',
			[
				'label' => esc_html__( 'Event Status Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'status_color',
			[
				'label' => esc_html__( 'Event Status Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'status_description',
			[
				'label' => esc_html__( 'Description of the Status', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Please join us for recpetion, dinner & dancing after the Ceremony - from 6:00pm until late.',
			]
		);
		$repeater->add_control(
			'status_description_size',
			[
				'label' => esc_html__( 'Status Description Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'description_color',
			[
				'label' => esc_html__( 'Description Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'icon',
			[
				'label' => esc_html__( 'Icon', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'fa4compatibility' => 'social',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]
		);
		$repeater->add_control(
			'location',
			[
				'label' => esc_html__( 'Event Location', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'ROYAL SONESTA RIVERFRONT',
			]
		);
		$repeater->add_control(
			'location_size',
			[
				'label' => esc_html__( 'Location Size', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
			]
		);
		$repeater->add_control(
			'location_color',
			[
				'label' => esc_html__( 'Location Color', 'silvuple' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$this->add_control( 
			'list',
			[
			    'label' => esc_html__('Menu Items', 'silvuple'),
			    'type' => \Elementor\Controls_Manager::REPEATER,
			    'fields' => $repeater->get_controls(),
			    'default' => [
					[
						'bio_links_description' => esc_html__( 'Basic Description and More', 'silvuple' ),
						'type' => esc_html__( 'Default', 'silvuple' ),
					],
				],
			]
		);
		$this->end_controls_section();
	}
	protected function render() { 
    // get our input from the widget settings.
    $settings = $this->get_settings_for_display();
    // get the individual values of the input
    $list = $settings['list'];

    echo do_shortcode('[silvuple-timeline list="' . base64_encode(serialize($list)) . '"]');
  }           
}